==> ae_kivy_auto_width-0.1.4.tar.gz: ae_kivy_auto_width-0.1.4/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# kivy_auto_width portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_auto_width/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_auto_width)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_auto_width/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_auto_width/coverage/ae_kivy_auto_width_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_auto_width/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_auto_width/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_auto_width/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_auto_width/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_auto_width)](
    https://libraries.io/pypi/ae-kivy-auto-width)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/#files)


## installation


Execute the following command for to use the ae.kivy_auto_width module in your
application. It will install ae.kivy_auto_width into your python (virtual) environment:
 
```shell script
pip install ae-kivy-auto-width
```

If you instead want to contribute to this portion then first fork
[the ae_kivy_auto_width repository at GitLab](https://gitlab.com/ae-group/ae_kivy_auto_width "ae.kivy_auto_width code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_auto_width):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_auto_width.html#module-ae.kivy_auto_width
"ae_kivy_auto_width documentation").

<!-- Common files version 0.1.61 deployed version 0.1.0 (with 0.1.61)
     to https://gitlab.com/ae-group as ae_kivy_auto_width module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-auto-width as namespace portion ae-kivy-auto-width.
-->

==> ae_kivy_auto_width-0.2.18.tar.gz: ae_kivy_auto_width-0.2.18/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# kivy_auto_width portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_auto_width/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_auto_width)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_auto_width/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_auto_width/coverage/ae_kivy_auto_width_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_auto_width/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_auto_width/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_auto_width/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_auto_width/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_auto_width)](
    https://libraries.io/pypi/ae-kivy-auto-width)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_auto_width)](
    https://pypi.org/project/ae-kivy-auto-width/#files)


## installation


execute the following command to use the ae.kivy_auto_width module in your
application. it will install ae.kivy_auto_width into your python (virtual) environment:
 
```shell script
pip install ae-kivy-auto-width
```

if you instead want to contribute to this portion then first fork
[the ae_kivy_auto_width repository at GitLab](https://gitlab.com/ae-group/ae_kivy_auto_width "ae.kivy_auto_width code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_auto_width):

```shell script
pip install -e .[dev]
```

the last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_auto_width.html#module-ae.kivy_auto_width
"ae_kivy_auto_width documentation").

<!-- common files version 0.2.77 deployed version 0.2.16 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_kivy_auto_width module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-auto-width as namespace portion ae-kivy-auto-width.
-->
